%define major 3
%define libname %mklibname ipset %{major}
%define develname %mklibname ipset -d

%ifarch %{arm}
%define kflavour kirkwood
%else
%define kflavour desktop
%endif

Summary:	Tools for managing sets of IP or ports with iptables
Name:		ipset
Version:	6.14
Release:	1
License:	GPLv2+
Group:		System/Kernel and hardware
Url:		http://ipset.netfilter.org/
Source0:	http://ipset.netfilter.org/%{name}-%{version}.tar.bz2
BuildRequires:	mnl-devel
BuildRequires:	kernel-%{kflavour}-devel > 3.1.5

%description
IP sets are a framework inside the Linux 2.4.x and 2.6.x kernel, which can be
administered by the ipset utility. Depending on the type, currently an IP set
may store IP addresses, (TCP/UDP) port numbers or IP addresses with MAC
addresses in a way, which ensures lightning speed when matching an entry
against a set.

ipset may be the proper tool for you, if you want to

 o store multiple IP addresses or port numbers and match against the collection
   by iptables at one swoop;

 o dynamically update iptables rules against IP addresses or ports without
   performance penalty;

 o express complex IP address and ports based rulesets with one single iptables
   rule and benefit from the speed of IP sets 

%package -n %{libname}
Summary:	Shared library for managing sets of IP or ports with iptables
Group:		System/Libraries

%description -n	%{libname}
IP sets are a framework inside the Linux 2.4.x and 2.6.x kernel, which can be
administered by the ipset utility. Depending on the type, currently an IP set
may store IP addresses, (TCP/UDP) port numbers or IP addresses with MAC
addresses in a way, which ensures lightning speed when matching an entry
against a set.

This package provides the shared library for managing sets of IP or ports with
iptables.

%package -n %{develname}
Summary:	Headers and static lib for ipset development
Group:		Development/C
Obsoletes:	ipset-devel < %{version}-%{release}
Provides:	ipset-devel = %{version}-%{release}

%description -n	%{develname}
IP sets are a framework inside the Linux 2.4.x and 2.6.x kernel, which can be
administered by the ipset utility. Depending on the type, currently an IP set
may store IP addresses, (TCP/UDP) port numbers or IP addresses with MAC
addresses in a way, which ensures lightning speed when matching an entry
against a set.

Install this package if you want do compile applications using the ipset
library.

%prep

%setup -q

%build
aclocal -I m4
autoreconf -fi
KPKG=kernel-%{kflavour}-devel
KDIR=$(rpm -ql $KPKG | grep '/usr/src/devel/[^/]*$')

%configure2_5x \
    --with-kbuild=$KDIR \
    --disable-static \
    --enable-shared \
    --disable-ltdl-install \
    --enable-settype-modules

%make

%install
%makeinstall_std

install -d %{buildroot}%{_libdir}/ipset

rm -f %{buildroot}%{_libdir}/*.la

%files
%doc ChangeLog ChangeLog.ippool
%{_sbindir}/*
%{_mandir}/man8/*.8*

%files -n %{libname}
%dir %{_libdir}/ipset
%{_libdir}/lib*.so.%{major}*

%files -n %{develname}
%dir %{_includedir}/libipset
%{_includedir}/libipset/*
%{_libdir}/*.so


%changelog
* Sat Nov 03 2012 Tomasz Pawel Gajc <tpg@mandriva.org> 6.14-1
+ Revision: 821753
- bump major to 3
- update to new version 6.14
- spec file clean

* Fri May 18 2012 Oden Eriksson <oeriksson@mandriva.com> 6.12.1-1
+ Revision: 799529
- also provide the modules dir
- 6.12.1
- libifiction because loadable ipset modules may follow

* Sun Feb 05 2012 Oden Eriksson <oeriksson@mandriva.com> 6.11-1
+ Revision: 771267
- add the devel sub package
- 6.11
- various cleanups

* Tue Jan 10 2012 Oden Eriksson <oeriksson@mandriva.com> 6.10-0
+ Revision: 759270
- 6.10
- sort of make it build. it would need to be made dkms aware or something...

* Sun Nov 06 2011 Andrey Bondrov <abondrov@mandriva.org> 6.9.1-1
+ Revision: 722587
- New version 6.9.1, don't hardcode kernel version and release

* Thu Apr 28 2011 Funda Wang <fwang@mandriva.org> 6.4-2
+ Revision: 659792
- do not build shared version of libipset, it is of no use

* Sun Apr 24 2011 Thomas Backlund <tmb@mandriva.org> 6.4-1
+ Revision: 658358
- update to 6.4 (#62965)

* Tue Nov 23 2010 Eugeni Dodonov <eugeni@mandriva.com> 4.4-1mdv2011.0
+ Revision: 600270
- Updated to 4.4.

* Wed Apr 07 2010 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 4.2-1mdv2010.1
+ Revision: 532850
- Updated to version 4.2 and dropped merged patch:
  ipset_upstream_alignment_fix.patch

* Sun Mar 14 2010 Oden Eriksson <oeriksson@mandriva.com> 2.4.9-4mdv2010.1
+ Revision: 519010
- rebuild

* Fri Sep 25 2009 Olivier Blin <blino@mandriva.org> 2.4.9-3mdv2010.0
+ Revision: 449109
- merge alignment fix from upstream: with -Werror, build is failing on
  alignment issue (from Arnaud Patard)

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 2.4.9-2mdv2010.0
+ Revision: 425373
- rebuild

* Sun Feb 15 2009 Thierry Vignaud <tv@mandriva.org> 2.4.9-1mdv2009.1
+ Revision: 340387
- new release

* Fri Dec 19 2008 Oden Eriksson <oeriksson@mandriva.com> 2.4.5-1mdv2009.1
+ Revision: 316262
- 2.4.5

* Sat Sep 13 2008 Oden Eriksson <oeriksson@mandriva.com> 2.3.3a-1mdv2009.0
+ Revision: 284446
- 2.3.3a

* Tue Jul 08 2008 Oden Eriksson <oeriksson@mandriva.com> 2.3.0-4mdv2009.0
+ Revision: 232774
- added P0 to fix build

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

* Thu Jan 24 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 2.3.0-2mdv2008.1
+ Revision: 157612
- spec file clean
- update to latest version
- update kernel headers
- compile with optflags
- spec file clean

* Sun Jan 13 2008 Thierry Vignaud <tv@mandriva.org> 2.2.9a-2mdv2008.1
+ Revision: 150301
- rebuild
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <blino@mandriva.org>
    - restore BuildRoot

* Fri Jul 13 2007 Adam Williamson <awilliamson@mandriva.org> 2.2.9a-1mdv2008.0
+ Revision: 51737
- new release 2.2.9a
- Import ipset



* Fri Aug  4 2006 Samir Bellabes <sbellabes@n4.mandriva.com> 2.2.9-1mdv2007.0
- new release.
- use mkrel tag
- include kernel headers in the package.

* Wed Aug 31 2005 Couriousous <couriousous@mandriva.org> 2.2.2-4mdk
- Fix plugin loading on x86_64

* Wed Aug 10 2005 Samir Bellabes <sbellabes@mandriva.com> 2.2.2-3mdk
- Fix missing PREFIX

* Tue Aug  2 2005 Olivier Blin <oblin@mandriva.com> 2.2.2-2mdk
- fix libdir on x86_64

* Fri Jul 29 2005 Samir Bellabes <sbellabes@mandriva.com> 2.2.2-1mdk
- first release
